<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'admin_init', 'custom_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'content'       => array( 
        array(
          'id'        => 'hello',
          'title'     => 'Hello',
          'content'   => 'Help section'
        )
      ),
      'sidebar'       => 'help'
    ),
    'sections'        => array( 
      array(
        'id'          => 'logo',
        'title'       => 'Logo'
      ),
      array(
        'id'          => 'bg',
        'title'       => 'Background'
      ),
      array(
        'id'          => 'socialicons',
        'title'       => 'Social Icons'
      ),
      array(
        'id'          => 'navmenu',
        'title'       => 'Navigation Menu'
      ),
      array(
        'id'          => 'slider',
        'title'       => 'Slider'
      ),
      array(
        'id'          => 'homepage',
        'title'       => 'Homepage Settings'
      ),
      array(
        'id'          => 'footer',
        'title'       => 'Footer'
      )
    ),
    'settings'        => array( 
      array(
        'id'          => 'logocolor',
        'label'       => 'Logo Color',
        'desc'        => 'Choose the Logo Color',
        'std'         => '#000',
        'type'        => 'colorpicker',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'logofontsize',
        'label'       => 'Logo Font Size',
        'desc'        => 'Change the size of your logo by modifying the value. This is in pixels.',
        'std'         => '55',
        'type'        => 'text',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'desc_size',
        'label'       => 'Description Text Size',
        'desc'        => 'This is the text size in pixels for the description line',
        'std'         => '14',
        'type'        => 'text',
        'section'     => 'logo',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'bgimage',
        'label'       => 'Background Image',
        'desc'        => 'Upload your Background Image',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'bg',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'facebookurl',
        'label'       => 'FaceBook Page URL',
        'desc'        => 'Enter your Facebook Page URL (Full Link)',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'socialicons',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'twitterid',
        'label'       => 'Twitter ID',
        'desc'        => 'Enter your Twitter ID',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'socialicons',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'hovercolor',
        'label'       => 'Navigation Menu Hover Color',
        'desc'        => 'Enter the Hover Color for the Menu Items in the Navigation Menu',
        'std'         => '#56a4b0',
        'type'        => 'colorpicker',
        'section'     => 'navmenu',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'menufontsize',
        'label'       => 'Navigation Menu Font Size',
        'desc'        => 'Enter the Font Size for the Navigation Menu Items',
        'std'         => '16',
        'type'        => 'text',
        'section'     => 'navmenu',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'noslides',
        'label'       => 'Number of Slides',
        'desc'        => 'Enter the number of slides you want to show in the slider',
        'std'         => '2',
        'type'        => 'text',
        'section'     => 'slider',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
	  array(
        'id'          => 'slide_cat',
        'label'       => 'Posts Category for Slider',
        'desc'        => 'Enter the category name from where you want to pull the slides',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'slider',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'cat1',
        'label'       => 'Category 1',
        'desc'        => 'Enter the Category name for Post Block 1',
        'std'         => 'Uncategorized',
        'type'        => 'text',
        'section'     => 'homepage',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'cat2',
        'label'       => 'Category 2',
        'desc'        => 'Enter the Category name for Post Block 2',
        'std'         => 'Uncategorized',
        'type'        => 'text',
        'section'     => 'homepage',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'cat3',
        'label'       => 'Category 3',
        'desc'        => 'Enter the Category name for Post Block 3',
        'std'         => 'Uncategorized',
        'type'        => 'text',
        'section'     => 'homepage',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'cat4',
        'label'       => 'Category 4',
        'desc'        => 'Enter the Category name for Post Block 4',
        'std'         => 'Uncategorized',
        'type'        => 'text',
        'section'     => 'homepage',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'cat5',
        'label'       => 'Category 5',
        'desc'        => 'Enter the Category name for Post Block 5. Three posts will be pulled from this category',
        'std'         => 'Uncategorized',
        'type'        => 'text',
        'section'     => 'homepage',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'cat6',
        'label'       => 'Category 6',
        'desc'        => 'Enter the Category name for Post Block 6. Three posts will be pulled from this category.',
        'std'         => 'Uncategorized',
        'type'        => 'text',
        'section'     => 'homepage',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'galcat',
        'label'       => 'Gallery Category',
        'desc'        => 'Enter the category for your Gallery. Upload Images with the posts as featured image.',
        'std'         => 'Uncategorized',
        'type'        => 'text',
        'section'     => 'homepage',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'aboutus',
        'label'       => 'About Us',
        'desc'        => 'Enter the About Us text here.',
        'std'         => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nulla semper tellus nisl, et imperdiet nisl egestas eu. Phasellus vel dignissim dolor, at tristique arcu. Aliquam eu bibendum neque, id lobortis tortor.',
        'type'        => 'textarea-simple',
        'section'     => 'footer',
        'rows'        => '6',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'phone',
        'label'       => 'Phone Number',
        'desc'        => 'Enter the Phone number here.',
        'std'         => '1-800-123-2345',
        'type'        => 'text',
        'section'     => 'footer',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'address',
        'label'       => 'Address',
        'desc'        => 'Enter your address here.',
        'std'         => '123, Some Street, Another State, Country, 110022',
        'type'        => 'text',
        'section'     => 'footer',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      ),
      array(
        'id'          => 'copyright',
        'label'       => 'Copyright',
        'desc'        => 'Enter copyright text here.',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'footer',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => ''
      )
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( 'option_tree_settings_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}